/* fxTest.C                                                                 */
/* Copyright (c) Genus Microprogramming, Inc. 1988-89  All Rights Reserved. */

/****************************************************************************

  This program demonstrates the usage of an effect. It is an example
  C routine for the PCX Effects Toolkit.

  To Compile: Microsoft C 5.x    cl  /c fxtest.c
                                 link fxtest,,,pcx_cs;

              Quick     C 2.x    QC  fxtest                          
                                 (press "Shift-F5" to run)
                           or    QCL fxtest.c /link pcx_cm;

              Lattice   C 3.2x   lc  -n fxtest
                                 link fxtest s\c,,,s\lc pcx_lcs fx_lcs;

              Turbo     C 2.x    tc  fxtest
                                 (Specify a PRJ file, 3 lines: fxtest     )
                                 (                             pcx_cs.lib )
                                 (                             fx_cs.lib  )
                                 (and press "Alt-R" to run                )
                           or    tcc fxtest pcx_cs.lib fx_cs.lib

  Microsoft C version 5.1                 Programmer: Chris Howard  5/07/89

*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include <malloc.h> /* Change to 'alloc.h' for Turbo C, remove for Lattice  */

/* Include the PCX Toolkit defines */
#include "pcxlib.h"
#include "fxlib.h"

/* Globals - DECLARE AS "char far" FOR LATTICE C                            */
int  pcxtype    =  pcxVGA_11;
char pcximage[] = "fxTest.PCX";
char pcxpal[800];

PCXVINFO vi[2];
PCXHEADER header;

char *bufptr;
int  bufmax     = 20000;

/**********/

void main(argc,argv)
int  argc;
char *argv[];

{
  long vfree,vreq,vptr;
  int  width,depth,wx2,wy2,retcode;

  /* Display program header */
  printf("\n");
  printf("͸\n");
  printf(" fxTest: Example Effect C Program                        PCX Effects 1.0x \n");
  printf(" Copyright (c) Genus Microprogramming, Inc. 1988-89  All Rights Reserved. \n");
  printf(";\n");
  printf("\n");

  /* Get a key, to begin */
  printf("Press a key to run . . .");
  getch();
  printf("\n\n");

  /* Allocate a larger toolkit buffer, to speed up file and display speed. */
  if ((bufptr = malloc(bufmax)) != NULL) {
    retcode = pcxSetBuffer(bufptr,bufmax);
  }

  /* Check if we have expanded memory, and display */
  if (pcxEMInstalled() == pcxSUCCESS) {
    vfree = pcxVirtualFree(pcxEMM);
    printf("Free EMM: %ld\n",vfree);
  }

  /* Display the amount of conventional free memory */
  vfree = pcxVirtualFree(pcxCMM);
  printf("Free CMM: %ld\n",vfree);

  /* Look at the current hardware, to find a B/W mode */
  pcxVideoInfo(vi);

  switch(vi[0].adapter) {
    case viCGA:
      pcxtype = pcxCGA_6;
      break;
    case viEGA:
      if (vi[0].display == viMDAdisp)
        pcxtype = pcxEGA_F;
      else
        pcxtype = pcxEGA_10;
      break;
    case viVGA:
      pcxtype = pcxVGA_11;
      break;
    case viHGC:
      pcxtype = pcxHERC;
      break;
    default:
      /* If we cannot determine a good type, set flag */
      pcxtype = -1;
      break;
  }

  /* If we found a mode, continue */
  if (pcxtype != viNONE) {

    /* Set the display type */
    pcxSetDisplay(pcxtype);

    /* Load the image */
    retcode = fxFileImage(pcxCMM,&vptr,pcximage);
    if (retcode == fxSUCCESS) {

      /* Change to graphics mode */
      pcxSetMode(pcxGRAPHICS);

      /* Calibrate the delay timer, and play a looping song */
      fxCalibrateDelay();
      fxPlayLoop(25);
      fxPlay("T120 MB O3 L32 C D E F G A B A G F E D ");

      /* Select our effect */
      fxSetEffect(fxRANDOM);
      fxSetGrain(8);

      /* and do it */
      retcode = fxVirtualEffect(vptr,0,0,fxNONE);

      /* Kill any remaining background music */
      fxPlayKill();

      /* Wait for a key */
      getch();

      /* Get back to text mode */
      pcxSetMode(pcxTEXT);

      /* Were we successful? */
      if (retcode != fxSUCCESS)
        printf("\npcxVirtualEffect Error: %d\n",retcode);

      /* Destroy the virtual buffer */
      fxFreeImage(vptr);

    }
    else {
      /* Could not load image */
      printf("\nCould not load image: %d . . .\n",retcode);
    }

  }
  else {
    /* We could not find a good mode */
    printf("\nCould not find a good mode type . . .\n");
  }

} /* end of main */

